==> uriparser-0.9.9-doc.zip: uriparser-0.9.9-doc/html/UriBase_8h.js <==
var UriBase_8h =
[
    [ "UriIp4Struct", "structUriIp4Struct.html", "structUriIp4Struct" ],
    [ "UriIp6Struct", "structUriIp6Struct.html", "structUriIp6Struct" ],
    [ "UriMemoryManagerStruct", "structUriMemoryManagerStruct.html", "structUriMemoryManagerStruct" ],
    [ "UriBool", "UriBase_8h.html#ab2e3d0e349df122b6e7da6d18c552655", null ],
    [ "UriBreakConversion", "UriBase_8h.html#a1a3015966b58da6e4bfa7b5cd2aa6a55", null ],
    [ "UriFuncCalloc", "UriBase_8h.html#a8b1d8969ad9d61b422ccdcbb8f720176", null ],
    [ "UriFuncFree", "UriBase_8h.html#a9339dfd72f2d3791a54bfa5821c3dcff", null ],
    [ "UriFuncMalloc", "UriBase_8h.html#a3e610352a54bfb0394c079b4a1653091", null ],
    [ "UriFuncRealloc", "UriBase_8h.html#ae29100564d371216fab74ff03ba1ce1c", null ],
    [ "UriFuncReallocarray", "UriBase_8h.html#a6057d82ce33c4f7f2ab3ddffd1f4e737", null ],
    [ "UriIp4", "UriBase_8h.html#af5264347e3da653b3139aac48b78ad7c", null ],
    [ "UriIp6", "UriBase_8h.html#a08f4ff2717dfde5806c712f59bc2d849", null ],
    [ "UriMemoryManager", "UriBase_8h.html#aee8a546540f539eb4ae16248f3ae1aaa", null ],
    [ "UriNormalizationMask", "UriBase_8h.html#a79cf947ebd1afabf3de855f2ff75772b", null ],
    [ "UriResolutionOptions", "UriBase_8h.html#a23a6259607a97b697372eb9456caa30d", null ],
    [ "UriBreakConversionEnum", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfcc", [
      [ "URI_BR_TO_LF", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfccaeb14ced8ebdf1dc3ec29796560e24feb", null ],
      [ "URI_BR_TO_CRLF", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfcca72892d5f467aa9a9f426f422c18e1f68", null ],
      [ "URI_BR_TO_CR", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfcca639a5fa2c0dab3ad144ee5e82cffcd55", null ],
      [ "URI_BR_TO_UNIX", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfccab92b817e0d5216fea9c8aadb6640b0d8", null ],
      [ "URI_BR_TO_WINDOWS", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfcca5de69aea88ea7f89db4fb165f2af5bb3", null ],
      [ "URI_BR_TO_MAC", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfcca2ccfad0748cdee4eb181cc255d76dfe6", null ],
      [ "URI_BR_DONT_TOUCH", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfccab44e9e9f6784deb77d288360c847df36", null ]
    ] ],
    [ "UriNormalizationMaskEnum", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400", [
      [ "URI_NORMALIZED", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400a9d4ae02baec352c6078dc615905b7eb1", null ],
      [ "URI_NORMALIZE_SCHEME", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400aed80a4777751564b865f26940169fc23", null ],
      [ "URI_NORMALIZE_USER_INFO", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400ab5268c99bba09a7624fc98f0780dc618", null ],
      [ "URI_NORMALIZE_HOST", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400a37be5f9fe86052f86fd122bb88e1ef4b", null ],
      [ "URI_NORMALIZE_PATH", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400ac944b8ea0cfa88f78fe4bfa72934ef80", null ],
      [ "URI_NORMALIZE_QUERY", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400a1cb6e4afe63436dda2a03e51a95a5147", null ],
      [ "URI_NORMALIZE_FRAGMENT", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400a4fc81bbbfdb1eef5da3a10177337be94", null ],
      [ "URI_NORMALIZE_PORT", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400a674d856133c44b65fb9a3b9bf225cd0f", null ]
    ] ],
    [ "UriResolutionOptionsEnum", "UriBase_8h.html#a1cdbeee44519b34292fab4b7d9213df1", [
      [ "URI_RESOLVE_STRICTLY", "UriBase_8h.html#a1cdbeee44519b34292fab4b7d9213df1acba2ad4d13d6d74094b5ae65ee4d82bb", null ],
      [ "URI_RESOLVE_IDENTICAL_SCHEME_COMPAT", "UriBase_8h.html#a1cdbeee44519b34292fab4b7d9213df1afc17d64c3fb7a315616512cd96b23f06", null ]
    ] ],
    [ "uriCompleteMemoryManager", "UriBase_8h.html#ae7811d209ed03e3a7e6e9a021a3a5fb4", null ],
    [ "uriEmulateCalloc", "UriBase_8h.html#a83070f1c356f702a168c92d0704e9d80", null ],
    [ "uriEmulateReallocarray", "UriBase_8h.html#afa27685237a224144d877356e83fc4f1", null ],
    [ "uriTestMemoryManager", "UriBase_8h.html#ac6bed1fb193bfe991cfb384bed299489", null ]
];

==> uriparser-1.0.0-doc.zip: uriparser-1.0.0-doc/html/UriBase_8h.js <==
var UriBase_8h =
[
    [ "UriIp4Struct", "structUriIp4Struct.html", "structUriIp4Struct" ],
    [ "UriIp6Struct", "structUriIp6Struct.html", "structUriIp6Struct" ],
    [ "UriMemoryManagerStruct", "structUriMemoryManagerStruct.html", "structUriMemoryManagerStruct" ],
    [ "UriBool", "UriBase_8h.html#ab2e3d0e349df122b6e7da6d18c552655", null ],
    [ "UriBreakConversion", "UriBase_8h.html#a1a3015966b58da6e4bfa7b5cd2aa6a55", null ],
    [ "UriFuncCalloc", "UriBase_8h.html#a8b1d8969ad9d61b422ccdcbb8f720176", null ],
    [ "UriFuncFree", "UriBase_8h.html#a9339dfd72f2d3791a54bfa5821c3dcff", null ],
    [ "UriFuncMalloc", "UriBase_8h.html#a3e610352a54bfb0394c079b4a1653091", null ],
    [ "UriFuncRealloc", "UriBase_8h.html#ae29100564d371216fab74ff03ba1ce1c", null ],
    [ "UriFuncReallocarray", "UriBase_8h.html#a6057d82ce33c4f7f2ab3ddffd1f4e737", null ],
    [ "UriIp4", "UriBase_8h.html#af5264347e3da653b3139aac48b78ad7c", null ],
    [ "UriIp6", "UriBase_8h.html#a08f4ff2717dfde5806c712f59bc2d849", null ],
    [ "UriMemoryManager", "UriBase_8h.html#aee8a546540f539eb4ae16248f3ae1aaa", null ],
    [ "UriNormalizationMask", "UriBase_8h.html#a79cf947ebd1afabf3de855f2ff75772b", null ],
    [ "UriResolutionOptions", "UriBase_8h.html#a23a6259607a97b697372eb9456caa30d", null ],
    [ "UriBreakConversionEnum", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfcc", [
      [ "URI_BR_TO_LF", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfccaeb14ced8ebdf1dc3ec29796560e24feb", null ],
      [ "URI_BR_TO_CRLF", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfcca72892d5f467aa9a9f426f422c18e1f68", null ],
      [ "URI_BR_TO_CR", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfcca639a5fa2c0dab3ad144ee5e82cffcd55", null ],
      [ "URI_BR_TO_UNIX", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfccab92b817e0d5216fea9c8aadb6640b0d8", null ],
      [ "URI_BR_TO_WINDOWS", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfcca5de69aea88ea7f89db4fb165f2af5bb3", null ],
      [ "URI_BR_TO_MAC", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfcca2ccfad0748cdee4eb181cc255d76dfe6", null ],
      [ "URI_BR_DONT_TOUCH", "UriBase_8h.html#a411334aa7c810d330d05a50504a7cfccab44e9e9f6784deb77d288360c847df36", null ]
    ] ],
    [ "UriNormalizationMaskEnum", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400", [
      [ "URI_NORMALIZED", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400a9d4ae02baec352c6078dc615905b7eb1", null ],
      [ "URI_NORMALIZE_SCHEME", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400aed80a4777751564b865f26940169fc23", null ],
      [ "URI_NORMALIZE_USER_INFO", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400ab5268c99bba09a7624fc98f0780dc618", null ],
      [ "URI_NORMALIZE_HOST", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400a37be5f9fe86052f86fd122bb88e1ef4b", null ],
      [ "URI_NORMALIZE_PATH", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400ac944b8ea0cfa88f78fe4bfa72934ef80", null ],
      [ "URI_NORMALIZE_QUERY", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400a1cb6e4afe63436dda2a03e51a95a5147", null ],
      [ "URI_NORMALIZE_FRAGMENT", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400a4fc81bbbfdb1eef5da3a10177337be94", null ],
      [ "URI_NORMALIZE_PORT", "UriBase_8h.html#ac0a876ae3fbf22bdfa8d3e4a24838400a674d856133c44b65fb9a3b9bf225cd0f", null ]
    ] ],
    [ "UriResolutionOptionsEnum", "UriBase_8h.html#a1cdbeee44519b34292fab4b7d9213df1", [
      [ "URI_RESOLVE_STRICTLY", "UriBase_8h.html#a1cdbeee44519b34292fab4b7d9213df1acba2ad4d13d6d74094b5ae65ee4d82bb", null ],
      [ "URI_RESOLVE_IDENTICAL_SCHEME_COMPAT", "UriBase_8h.html#a1cdbeee44519b34292fab4b7d9213df1afc17d64c3fb7a315616512cd96b23f06", null ]
    ] ],
    [ "uriCompleteMemoryManager", "UriBase_8h.html#ae7811d209ed03e3a7e6e9a021a3a5fb4", null ],
    [ "uriEmulateCalloc", "UriBase_8h.html#a83070f1c356f702a168c92d0704e9d80", null ],
    [ "uriEmulateReallocarray", "UriBase_8h.html#afa27685237a224144d877356e83fc4f1", null ],
    [ "uriTestMemoryManager", "UriBase_8h.html#ac6bed1fb193bfe991cfb384bed299489", null ],
    [ "uriTestMemoryManagerEx", "UriBase_8h.html#a66c43e01f60bd2ca427bda480baf403c", null ]
];
